#  petname: library for generating human-readable, random names
#           for objects (e.g. hostnames, containers, blobs)
#
#  Copyright 2014 Dustin Kirkland <dustin.kirkland@gmail.com>
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


import random
from .english import adverbs, adjectives, names


def Adverb():
    return random.choice(adverbs)

def Adjective():
    return random.choice(adjectives)

def Name():
    return random.choice(names)

def Generate(words, separator):
    if words == 1:
        return Name()
    elif words == 2:
        return Adjective() + separator + Name()
    petname = []
    for i in range(0, words - 2):
        petname.append(Adverb())
    petname.append(Adjective())
    petname.append(Name())
    return separator.join(petname)



#!/usr/bin/env python
#
# petname
#
# Copyright 2014 Dustin Kirkland <dustin.kirkland@gmail.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import argparse
import petname
import sys

def main():
    parser = argparse.ArgumentParser(description='Generate human readable random names')
    parser.add_argument('-w', '--words', help='Number of words in name, default=2', default=2)
    parser.add_argument('-s', '--separator', help='Separator between words, default="-"', default="-")
    parser.options = parser.parse_args()

    sys.stdout.write(petname.Generate(int(parser.options.words), parser.options.separator) + "\n")

if __name__ == "__main__":
    main()



#!/usr/bin/env python3
#
# petname - library for generating human-readable, random names
#           for objects (e.g. hostnames, containers, blobs)
# Copyright (c) 2013 Casey Marshall <casey.marshall@gmail.com>
#
# ssh-import-id is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 3.
#
# ssh-import-id is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ssh-import-id.  If not, see <http://www.gnu.org/licenses/>.

import os
from setuptools import setup

try:
    readme = open(os.path.join(os.path.dirname(__file__), "README.md")).read()
except:
    readme = "See: http://pypi.python.org/pypi?name=petname&:action=display_pkginfo"

setup(
    name='petname',
    description='Generate human-readable, random object names',
    long_description=readme,
    version='1.12',
    author='Dustin Kirkland',
    author_email='dustin.kirkland@gmail.com',
    license="Apache2",
    keywords="random name uuid",
    url='https://launchpad.net/petname',
    platforms=['any'],
    packages=['petname'],
    entry_points={
        'console_scripts': [
            'petname = petname.__main__:main',
        ]
    },
)
